@@ -102,61 +102,30 @@ expect_identical(
 
 
 context("modify magrittr")
-if(suppressWarnings(require(magrittr, quietly = TRUE))){
-    expect_identical(
-        dfs %>% modify( {
-            b_total = sum_row(vars(from("b_1") & to("b_5")))
-        }), 
-        result_dfs
-    )
-    
-    expect_identical(
-        dfs %>% modify( {
-            b_total = sum_row(vars(b_1 %to% b_5))
-        }), 
-        result_dfs
-    )
-    
-    expect_identical(
-        dfs %>% modify( {
-            b_total = sum_row(b_1 %to% b_5)
-        }), 
-        result_dfs
-    )
-    
-} else {
-    cat("magrittr not found\n")
-}
 
-# example with dplyr
-context("modify dplyr")
-if(suppressWarnings(require(dplyr, quietly = TRUE))){
-    
-    expect_identical(
-        tbl_df(dfs) %>% modify( {
-            b_total = rowSums(vars(from("b_1") & to("b_5")))
-        }), 
-        tbl_df(result_dfs)
-    )
-    
-    expect_identical(
-        tbl_df(dfs) %>% modify( {
-            b_total = rowSums(vars(b_1 %to% b_5))
-        }), 
-        tbl_df(result_dfs)
-    )
-    
-    expect_identical(
-        tbl_df(dfs) %>% modify( {
-            b_total = sum_row(b_1 %to% b_5)
-        }), 
-        tbl_df(result_dfs)
-    )
-    
-    
-} else {
-    cat("dplyr not found\n")
-}
+expect_identical(
+    dfs %>% modify( {
+        b_total = sum_row(vars(from("b_1") & to("b_5")))
+    }), 
+    result_dfs
+)
+
+expect_identical(
+    dfs %>% modify( {
+        b_total = sum_row(vars(b_1 %to% b_5))
+    }), 
+    result_dfs
+)
+
+expect_identical(
+    dfs %>% modify( {
+        b_total = sum_row(b_1 %to% b_5)
+    }), 
+    result_dfs
+)
+
+
+
 
 context("modify_if")
 set.seed(1)
@@ -224,29 +193,7 @@ expect_error(modify_if(dfs2,test %in% 2:4,  {.N = 42}))
 
 
 result_dfs2$random_numer = NULL
-context("modify_if dplyr")
-if(suppressWarnings(require(dplyr, quietly = TRUE))){
-    expect_identical(
-        modify_if(tbl_df(dfs2), test %in% 2:4,
-                  {
-                      b_total = sum_row(b_1 %to% b_5)
-                      aa = aa + 1
-                  }), 
-        tbl_df(result_dfs2)
-    )
-    
-    expect_error(
-        modify_if(tbl_df(dfs2), test %in% 2:4,
-                  {
-                      a_total = sum_row(a_1 %to% a_5)
-                      b_total = sum_row(b_1 %to% b_5)
-                      aa = aa + 1
-                  })
-    )
-    
-} else {
-    cat("dplyr not found\n")
-}
+
 
 
 result_dfs2$b_total = NULL
